@@ -1,13 +1,12 @@
 #![no_std]
 #![no_main]
 
-extern crate agb;
 extern crate alloc;
 
 use alloc::boxed::Box;
 
 #[agb::entry]
-fn main() -> ! {
+fn main(_gba: agb::Gba) -> ! {
     loop {
         let b = Box::new(1);
         agb::println!("dynamic allocation made to {:?}", &*b as *const _);
