@@ -1,14 +1,10 @@
 #![no_std]
 #![no_main]
 
-extern crate agb;
-
 use agb::sound;
 
 #[agb::entry]
-fn main() -> ! {
-    let gba = agb::Gba::new();
-
+fn main(gba: agb::Gba) -> ! {
     gba.sound.enable();
 
     let sweep_settings = sound::dmg::SweepSettings::default();
