@@ -1,12 +1,11 @@
 use crate::memory_mapped::MemoryMapped;
 use bitflags::bitflags;
 
+use modular_bitfield::BitfieldSpecifier;
 use video::Video;
 
-use self::object::ObjectControl;
+use self::object::ObjectController;
 
-/// Graphics mode 0. Four regular backgrounds.
-pub mod background;
 /// Graphics mode 3. Bitmap mode that provides a 16-bit colour framebuffer.
 pub mod bitmap3;
 /// Graphics mode 4. Bitmap 4 provides two 8-bit paletted framebuffers with page switching.
@@ -19,6 +18,8 @@ pub mod object;
 pub mod palette16;
 /// Data produced by agb-image-converter
 pub mod tile_data;
+/// Graphics mode 0. Four regular backgrounds.
+pub mod tiled;
 /// Giving out graphics mode.
 pub mod video;
 
@@ -69,8 +70,8 @@ pub struct Display {
 pub struct ObjectDistribution {}
 
 impl ObjectDistribution {
-    pub fn get(&mut self) -> ObjectControl {
-        ObjectControl::new()
+    pub fn get(&mut self) -> ObjectController {
+        ObjectController::new()
     }
 }
 
@@ -88,6 +89,9 @@ unsafe fn set_graphics_mode(mode: DisplayMode) {
     let current = current & (!0b111);
     let s = current | (mode as u16 & 0b111);
 
+    // disable blank screen
+    let s = s & !(1 << 7);
+
     DISPLAY_CONTROL.set(s);
 }
 
@@ -109,6 +113,7 @@ pub fn busy_wait_for_vblank() {
     while VCOUNT.get() < 160 {}
 }
 
+#[derive(BitfieldSpecifier, Clone, Copy)]
 pub enum Priority {
     P0 = 0,
     P1 = 1,
